@@ -8,14 +8,11 @@ use Tk::Font;
 use X11::Protocol;
 
 
-=head debug 
-
 $SIG{__DIE__} = sub { print &pile;};
 
 sub pile {
   my $i=0;
   my $str;
-  $i ++ while (caller($i))[0] =~ /^Error/;
   while(my ($p,$f,$l) = caller($i)) {
     $str .= "\t$f:$l ($p) \n";
     $i++;
@@ -23,13 +20,11 @@ sub pile {
   return $str;
 }
 
-=cut
-
 package Tk::SlideShow;
 
 use vars qw($VERSION);
 
-$VERSION='0.01';
+$VERSION='0.02';
 
 #
 # Class to manage a dictionnary of objects
@@ -42,7 +37,7 @@ sub Exists {my ($class,$cle) = @_; return ${$class."::dict"}{$cle};}
 
 sub Get {
   my ($class,$cle) = @_;
-  warn "$class($cle) inconue\n" unless exists ${$class."::dict"}{$cle};
+  warn "$class('$cle') unknown\n" unless exists ${$class."::dict"}{$cle};
   return ${$class."::dict"}{$cle} || $class->null;
 }
 
@@ -63,7 +58,7 @@ package Tk::SlideShow;
 my ($can,$H,$W,$xprot,$present);
 my $mw;
 my $mode = 'X11';
-my $family = "utopia";
+my $family = "charter";
 use vars qw($inMainLoop $nextslide $jumpslide);
 $nextslide = 0;
 sub var_getset{
@@ -76,19 +71,19 @@ sub family {
   if (defined $newfamily) {$family = $newfamily;}
   return $family;
 }
-sub f {return $can->Font(family  => $family, point   => int(150*(shift || 1)));}
-sub ff {return $can->Font(family  => 'courier', point   => int(250*(shift || 1)));}
-sub f0_5  {return  $can->Font(family  => $family, point   => 200);}
-sub f1    {return  $can->Font(family  => $family, point   => 250);}
-sub f1_5  {return  $can->Font(family  => $family, point   => 375);}
-sub ff0_5 {return $can->Font(family  => "courier", point   => 200);}
-sub ff1   {return $can->Font(family  => "courier", point   => 250);}
-sub ff2   {return $can->Font(family  => "courier", point   => 350);}
-sub ff3   {return $can->Font(family  => "courier", point   => 550);}
-sub f2    {return  $can->Font(family  => $family, point   => 500);}
-sub f3 {return  $can->Font(family  => $family, point => 750);}
-sub f4 {return  $can->Font(family  => $family, point => 1000);}
-sub f5 {return  $can->Font(family  => $family, point => 1250);}
+sub f {return $can->Font('family'  => $family, point   => int(150*(shift || 1)));}
+sub ff {return $can->Font('family'  => 'courier', point   => int(250*(shift || 1)));}
+sub f0_5  {return  $can->Font('family'  => $family, point   => 200);}
+sub f1    {return  $can->Font('family'  => $family, point   => 250);}
+sub f1_5  {return  $can->Font('family'  => $family, point   => 375);}
+sub ff0_5 {return $can->Font('family'  => "courier", point   => 200);}
+sub ff1   {return $can->Font('family'  => "courier", point   => 250);}
+sub ff2   {return $can->Font('family'  => "courier", point   => 350);}
+sub ff3   {return $can->Font('family'  => "courier", point   => 550);}
+sub f2    {return  $can->Font('family'  => $family, point   => 500);}
+sub f3 {return  $can->Font('family'  => $family, point => 750);}
+sub f4 {return  $can->Font('family'  => $family, point => 1000);}
+sub f5 {return  $can->Font('family'  => $family, point => 1250);}
 
 
 sub mw { return $mw;}
@@ -111,8 +106,14 @@ sub title_se {
 # internal function for internals needs
 my $current_item = "";
 
-sub enter {$current_item = ($can->gettags('current'))[0];}
-sub leave {$current_item = "";}
+sub enter {
+  $current_item = ($can->gettags('current'))[0]; 
+  # print "entering $current_item\n"; 
+}
+sub leave {
+  # print "leaving $current_item\n"; 
+  $current_item = "";
+}
 
 sub exec_if_current {
   my ($c,$tag,$fct,@ARGS) = @_;
@@ -137,6 +138,7 @@ sub init {
   $c->configure(-height,$H,-width,$W);
   $c->pack;
   $present->init_bindings;
+  $present->init_choosers;
   return $present;
 }
 
@@ -168,6 +170,11 @@ sub save {
   $mw->Tk::bind('Tk::SlideShow','<s>', [\&Tk::SlideShow::Placeable::save,$present]);
 }
 
+sub init_choosers {
+  Tk::SlideShow::Sprite->initFontChooser;
+  Tk::SlideShow::Sprite->initColorChooser;
+}
+
 sub load {
   shift;
   my $numero = $present->currentName;
@@ -222,8 +229,8 @@ sub init_bindings {
   $c->bind('all', '<Any-Enter>' => \&enter);
   $c->bind('all', '<Any-Leave>' => \&leave);
   $c->CanvasFocus;
-  $m->Tk::bind('Tk::SlideShow','<3>', \&shiftarrive);
-  $m->Tk::bind('Tk::SlideShow','<Control-3>', \&unshiftarrive);
+  $m->Tk::bind('Tk::SlideShow','<3>', \&shiftaction);
+  $m->Tk::bind('Tk::SlideShow','<Control-3>', \&unshiftaction);
   $m->Tk::bind('Tk::SlideShow','<KeyPress-space>', $setnextslide);
   $m->Tk::bind('Tk::SlideShow','<KeyPress-BackSpace>', $setprevslide);
   $m->Tk::bind('Tk::SlideShow','<Alt-q>', sub {$m->destroy; exit});
@@ -261,8 +268,8 @@ sub wait {
 sub clean { 
   my $class = shift;
   $can->delete('all'); 
-  $present->{'arrive'}= [];
-  $present->{'save_arrive'}= [];
+  $present->{'action'}= [];
+  $present->{'save_action'}= [];
   Tk::SlideShow::Placeable->Clean;
   return $class;
 }
@@ -272,7 +279,7 @@ sub a_warp {
   for my $tag (@tags) {
     my $bottom = ($can->bbox($tag))[3];
     $can->move($tag,0,0-$bottom);
-    push @{$present->{'arrive'}},[$tag,'a_warp',$bottom];
+    push @{$present->{'action'}},[$tag,'a_warp',$bottom];
   }
   return $class;
 }
@@ -283,7 +290,7 @@ sub a_top {
   for my $tag (@tags) {
     my $bottom = ($can->bbox($tag))[3];
     $can->move($tag,0,0-$bottom);
-    push @{$present->{'arrive'}},[$tag,'a_top',$bottom];
+    push @{$present->{'action'}},[$tag,'a_top',$bottom];
   }
   return $class;
 }
@@ -293,7 +300,7 @@ sub a_bottom {
   for my $tag (@tags) {
     my $top = ($can->bbox($tag))[1];
     $can->move($tag,0,$H-$top);
-    push @{$present->{'arrive'}},[$tag,'a_bottom',$top];
+    push @{$present->{'action'}},[$tag,'a_bottom',$top];
   }
   return $class;
 }
@@ -303,7 +310,7 @@ sub a_left {
   for my $tag (@tags) {
     my $right = ($can->bbox($tag))[2];
     $can->move($tag,0-$right,0);
-    push @{$present->{'arrive'}},[$tag,'a_left',$right];
+    push @{$present->{'action'}},[$tag,'a_left',$right];
   }
   return $class;
 }
@@ -313,16 +320,23 @@ sub a_right {
   for my $tag (@tags) {
     my $left = ($can->bbox($tag))[0];
     $can->move($tag,$W-$left,0);
-    push @{$present->{'arrive'}},[$tag,'a_right',$left];
+    push @{$present->{'action'}},[$tag,'a_right',$left];
   }
   return $class;
 }
 
-sub shiftarrive {
-  my $a = shift @{$present->{'arrive'}};
+sub a_multipos {
+  my ($class,$tag,$nbpos,@options) = @_;
+  for my $i (1..$nbpos) {
+    push @{$present->{'action'}},[$tag,'a_chpos',$i,@options];
+  }
+}
+
+sub shiftaction {
+  my $a = shift @{$present->{'action'}};
   my $c = $can;
   return unless $a;
-  push @{$present->{'save_arrive'}},$a;
+  push @{$present->{'save_action'}},$a;
   my ($tag,$maniere,$dest) = @$a;
   my $step = 50;
   $maniere eq 'a_top'  and 
@@ -335,13 +349,21 @@ sub shiftarrive {
     and do {for(my $i=0;$i<$step;$i++){$c->move($tag,($dest-$W)/$step,0); $c->update;}};
   $maniere eq 'a_warp'
     and do {$c->move($tag,0,$dest);};
+  $maniere eq 'a_chpos' and 
+    do {
+      my ($tag,$m,$i,@options) = @$a;
+      #print "doing $m on tag $tag i=$i\n";
+      my $sprite = Tk::SlideShow::Sprite->Get($tag);
+      $sprite->chpos($i,@options);
+    };
+      
 
 }
-sub unshiftarrive {
-  my $a = pop @{$present->{'save_arrive'}};
+sub unshiftaction {
+  my $a = pop @{$present->{'save_action'}};
   my $c = $can;
   return unless $a;
-  unshift @{$present->{'arrive'}},$a;
+  unshift @{$present->{'action'}},$a;
   my ($tag,$maniere,$dest) = @$a;
   my $step = 50;
   $maniere eq 'a_top'  and
@@ -354,6 +376,15 @@ sub unshiftarrive {
     and do {for(my $i=0;$i<$step;$i++){$c->move($tag,($W-$dest)/$step,0); $c->update;}};
   $maniere eq 'a_warp'
     and do {$c->move($tag,0,-$dest);};
+  $maniere eq 'a_chpos' and 
+    do {
+      my ($tag,$m,$i,@options) = @$a;
+      return unless $i>0;
+      $i--;
+      #print "undoing $m on tag $tag i=$i\n";
+      my $sprite = Tk::SlideShow::Sprite->Get($tag);
+      $sprite->chpos($i,@options);
+    };
 
 }
 
@@ -393,16 +424,15 @@ sub play {
     $jumpslide = 0;
     $current =  $present->current;
     my $diapo = $present->{'slides'}[$current];
-    print "Executing slide $current\n";
+    print "Executing slide number $current\n";
     $present->start_slide;
     &{$diapo->code};
     if (defined $timetowait) {
-      $mw->update;
       print "Sleeping $timetowait second\n";
-      sleep($timetowait);
-      if ($current == $nbslides-1) {
-	last ;
-      }
+      $mw->update;
+      sleep $timetowait;
+      last if $current == $nbslides-1 ;
+      print "Next one;\n";
     } else {
       $present->wait;
     }
@@ -415,14 +445,28 @@ sub play {
 }
 
 sub latexheader {
-  return "\\documentclass{article}
+  my ($p,$value) = @_;
+
+  return ($p->{'latexheader'} || 
+	  "\\documentclass{article}
 \\usepackage{graphicx}
 \\begin{document}
-";
+")
+    unless defined $value;
+
+  $p->{'latexheader'} = $value;
+  return $p;
 }
 
 sub latexfooter {
-  return "\\end{document}";
+  my ($p,$value) = @_;
+
+  return ($p->{'latexfooter'} || 
+	  "\\end{document}")
+    unless defined $value;
+
+  $p->{'latexfooter'} = $value;
+  return $p;
 }
 
 # saving diapo in a single latex file
@@ -489,7 +533,8 @@ sub Framed {return Tk::SlideShow::Sprite::framed(@_);}
 sub Image {return Tk::SlideShow::Sprite::image(@_);}
 sub Anim {return Tk::SlideShow::Sprite::anim(@_);}
 
-
+sub TickerTape {return Tk::SlideShow::Sprite::tickertape(@_);}
+sub Compuman {return Tk::SlideShow::Sprite::compuman(@_);}
 
 package Tk::SlideShow::Diapo;
 
@@ -619,9 +664,9 @@ sub save {
   my $numero = $slides->currentName;
   my $dfltfname = "slide-$numero.pl";
   my %files = ();
-  print "sauvegarde du slide $numero\n";
+  print "saving slide $numero\n";
   foreach my $cl (@classes) {
-    print "Scanning de la classe $cl\n";
+    #print "Scanning class $cl\n";
     while (my $s = $cl->Each) {
       my $id = $s->id;
       next if $id eq '__null__';
@@ -631,7 +676,7 @@ sub save {
     }
   }
   while(my($k,$v) = each %files) {
-    print "gnration du fichier $k\n";
+    print "Generating file  $k\n";
     open(OUT,">$k") or die;
     print OUT $v;
     close OUT;
@@ -679,14 +724,25 @@ use vars qw(@ISA); @ISA = qw(Tk::SlideShow::Placeable);
 
 Tk::SlideShow::Placeable->AddClass('Tk::SlideShow::Sprite');
 
+# keeping memory of tag to sprite association
+my %tagtosprite;
+
 sub New {
-  my ($class,$c,$id) = @_;
-  my $s = $class->SUPER::New($c,$id);
+  my ($class,$id) = @_;
+  my $s = $class->SUPER::New($id);
   $s->{'link'}= [];
   bless $s;
+  $tagtosprite{$id} = $s;
   return $s;
 }
 
+sub getSpriteof {
+  my ($class,$tag) = @_;
+  return $tagtosprite{$tag} if exists $tagtosprite{$tag};
+  return undef;
+}
+
+
 sub null {
   my ($class) = @_;
   my $s = $class->SUPER::New('__null__');
@@ -696,15 +752,78 @@ sub null {
 
 sub evalplace {
   my $s = shift;
-  return sprintf("place(%d,%d)",$s->x,$s->y);
+  my $ret = "";
+  if (exists $s->{'multipos'}) {
+    $s->{'multipos'}[$s->{'curposindex'}] = [$s->x,$s->y];
+    $ret .= "multipos(". join(',',map {join(',',@$_)} @{$s->{'multipos'}}). ")";
+  } else {
+    $ret .= sprintf("place(%d,%d)",$s->x,$s->y);
+  }
+  $ret .= sprintf("->fontFamily('%s')",$s->fontFamily) 
+    if exists $s->{'-font'} && $s->{'-font'};
+  $ret .= sprintf("->color('%s')",$s->color) 
+    if exists $s->{'-color'} && $s->{'-color'};
+  return $ret;
 }
 
+
 sub place {
   my ($s,$x,$y) = @_;
   my ($dx,$dy) = ($x-$s->x,$y-$s->y);
   Tk::SlideShow->can->move($s->id,$dx,$dy);
   $s->{'x'} = $x;
   $s->{'y'} = $y;
+  return $s;
+}
+
+sub multipos {
+  my ($s,@xy) = @_;
+  my $i = 0;
+  while(@xy) {$s->{'multipos'}[$i] = [splice(@xy,0,2)]; $i++}
+  $s->place(@{$s->{'multipos'}[0]});
+}
+
+sub chpos {
+  my ($s,$i,%options) = @_;
+  my $tag = $s->{'id'};
+  my $lasti;
+  $s->{'multipos'} = [] unless exists $s->{'multipos'};
+
+  if (exists $s->{'curposindex'}) {
+    $lasti = $s->{'curposindex'};
+  } else {
+    $lasti = 0;
+  }
+  #print "Saving pos $lasti for $tag\n";
+  my ($x,$y) = ($s->x,$s->y);
+  $s->{'multipos'}[$lasti] = [$x,$y];
+
+  #print "moving tag $tag to position $i\n";
+  $s->{'multipos'}[$i] = [$H/2,$W/2] 
+    unless defined $s->{'multipos'}[$i];
+  my ($destx,$desty) = @{$s->{'multipos'}[$i]};
+  # number of pixel per second
+  my $speed = $options{'-speed'} || 500;
+  my $distance = (($destx-$x)**2+($desty-$y)**2)**.5;
+  #printf ("deplacement de %d,%d a $destx,$desty\n",$x,$y);
+  my $steps = $options{'-steps'} || 50;
+  my $step = int($distance/$steps);
+  my $dt = $distance / $speed;
+  #print "dt=$dt  distance=$distance step=$step\n";
+  my ($x0,$y0) = ($x,$y);
+  my $dx = ($destx-$x0)/$step;
+  my $dy = ($desty-$y0)/$step;
+  for (my $t=1; $t<=$step; $t++) {
+    my $tx = $x0+$t*$dx;
+    my $ty = $y0+$t*$dy;
+    my ($tdx,$tdy)  = (int($tx-$x),int($ty-$y));
+    $can->move($tag,$tdx,$tdy);
+    $x += $tdx; $y += $tdy;
+    $can->update;
+    select(undef,undef,undef,$dt/$step);
+  }
+  ($s->{'x'},$s->{'y'}) = ($destx, $desty);
+  $s->{'curposindex'} = $i;
 }
 
 sub text {
@@ -715,19 +834,118 @@ sub text {
   my $c = Tk::SlideShow->can;
   my $item = 
     $c->createText
-      (Tk::SlideShow->w/2,Tk::SlideShow->h/ 2,'-text', $text,-font, Tk::SlideShow->f1, -tags,$id);
+      (Tk::SlideShow->w/2,Tk::SlideShow->h/ 2,'-text', $text,
+       -font, Tk::SlideShow->f1, -tags,$id);
   $c->itemconfigure($item,@_);
-
+  $s->{-font} = "";   bindfontchoosermenu($id);
+  $s->{-color} = ""; bindcolorchoosermenu($id);
   $s->pan(1);
   return $s;
 }
 
+# managing font for Sprites with text
+{
+  my (%f,@f);
+  my $fontmenu; my $lbox;
+  my ($curit, $cursp);
+  sub initFontChooser {
+    open(FONT,"xlsfonts |") or die;
+    while(<FONT>) {next unless /^-/; my @a = split /-/; $f{$a[2]} = 1;}
+    close (FONT);
+    $fontmenu = $mw->Menu;
+    my $lb = $fontmenu->Scrolled('Listbox')->pack;
+    $lbox = $lb->Subwidget('listbox');
+    $lbox->bind('<Double-1>',
+		sub {
+		  my $fontindex = $lbox->curselection;
+		  if (defined $curit and defined $cursp) {
+		    my $font = $can->itemcget($curit,-font);
+		    $font->configure('-family',$f[$fontindex]);
+		    #print "on passe a la fontindex=$fontindex :".$f[$fontindex]."\n";
+		    $cursp->{-font} = $f[$fontindex];
+		  }
+		  #print "item = $curit\n";
+		  $fontmenu->unpost;
+		  $curit =$cursp = undef;
+		});
+    @f = sort keys %f;
+    $lb->insert('end',@f);
+  }
+  sub bindfontchoosermenu {
+    my $tagorid = shift;
+    my $c = Tk::SlideShow->can;
+    $c->bind($tagorid,'<Double-1>',
+	     sub {
+	       my $e = (shift)->XEvent;
+	       $curit = $current_item;
+	       $cursp = $tagtosprite{$curit} 
+		 if defined $curit;
+	       $fontmenu->post($e->X,$e->Y);
+	       }
+	    );
+  }
+  sub fontFamily {
+    my ($s,$fam) = @_;
+    return $s->{-font} unless defined $fam;
+    $s->{-font} = $fam;
+    my $font = $can->itemcget($s->{'id'},-font);
+    $font->configure('-family',$fam);
+    return $s;
+  }
+}
+# managing color for Sprites with color
+{
+  my (%color,@color);
+  my $colormenu; my $lbox;
+  my ($curit, $cursp);
+  sub initColorChooser {
+    $colormenu = $mw->Menu;
+    @color = qw(red green blue yellow black purple magenta);
+    my $lb = $colormenu->Scrolled('Listbox')->pack;
+    $lbox = $lb->Subwidget('listbox');
+    $lb->insert('end',@color);
+    $lbox->bind('<Double-1>',
+		sub {
+		  my $colorindex = $lbox->curselection;
+		  if (defined $curit and defined $cursp) {
+		    $can->itemconfigure($curit,-fill,$color[$colorindex]);
+		    #print "on passe a la couleur=$colorindex :".$color[$colorindex]."\n";
+		    $cursp->{-color} = $color[$colorindex] ;
+		  }
+		  #print "item = $curit\n";
+		  $colormenu->unpost;
+		  $curit =$cursp = undef;
+		});
+  }
+  sub bindcolorchoosermenu {
+    my $tagorid = shift;
+    my $c = Tk::SlideShow->can;
+    $c->bind($tagorid,'<Double-2>',
+	     sub {
+	       my $e = (shift)->XEvent;
+	       $curit = $current_item;
+	       $cursp = $tagtosprite{$curit} 
+		 if defined $curit;
+	       $colormenu->post($e->X,$e->Y);
+	       }
+	    );
+  }
+  sub color {
+    my ($s,$col) = @_;
+    return $s->{-color} unless defined $col;
+    $s->{-color} = $col;
+    $can->itemconfigure($s->{'id'},-fill,$col);
+    #print "on met $s->{'id'} en $col\n";
+    return $s;
+  }
+}
+
 sub point {
   shift; my $id = shift;
   my $s = Tk::SlideShow::Sprite->New($id);
   my $c = Tk::SlideShow->can;
   my $item = 
-    $c->createOval(qw(0 0 10 10),-fill,'blue', -tags ,$id);
+    $c->createOval(qw(0 0 5 5),-fill,'blue', -tags ,$id);
   $s->pan(1);
   return $s;
 }
@@ -752,10 +970,10 @@ sub anim {
 	   [ sub { 
 	       my ($c,$s,$im) = @_;
 	       if ($s->{'state'}) {
-		 print "stopping ".$s->id."\n";
+		 #print "stopping ".$s->id."\n";
 		 $im->stop_animation;
 	       } else {
-		 print "starting ".$s->id."\n";
+		 #print "starting ".$s->id."\n";
 		 $im->start_animation($freq); 
 	       }
 	       $s->{'state'} =  1 - $s->{'state'};
@@ -792,7 +1010,7 @@ sub window {
 
   $c->createWindow(Tk::SlideShow->w/2, Tk::SlideShow->h/2,
 		   -window, $window, -tags,$id, @_);
-  printf("%s %s window\n",Tk::SlideShow->w/2, Tk::SlideShow->h/2);
+  #printf("%s %s window\n",Tk::SlideShow->w/2, Tk::SlideShow->h/2);
   $s->pan(3);
   return $s;
 }
@@ -868,6 +1086,57 @@ sub framed {
   $s->pan(1);
   return $s;
 }
+sub compuman {
+  my ($p,$id) = @_;
+  my $s = Tk::SlideShow::Sprite->New($id);
+  my @o1 = (-width ,4,-fill, 'black', -tags ,$id);
+  my @o2 = (-fill,'blue', -tags ,$id);
+  my @o3 = (-width ,4,-fill,'red', -tags ,$id);
+  $can->createLine(qw(10 20 10 40 25 40 25 50),@o1); #chair
+  $can->createLine(qw(15 15 15 35 30 35 30 50 35 50),@o1); # body
+  $can->createOval(qw(11 11 18 18),@o2); # head
+  $can->createLine(qw(15 25 30 25),@o1); # feet
+  $can->createLine(qw(30 27 40 22),@o3); # keyborad
+  $can->createPolygon(qw(35 20 40 0 55 10 55 20),@o3); # ecran
+  $can->createLine(qw(45 20 45 30 35 30 35 30),@o3); # 
+  ($s->{'x'},$s->{'y'}) = (0,0);
+  $s->pan(1);
+  return $s;
+}
+
+sub tickertape {
+  my ($p,$id,$text,$len,@options) = @_;
+
+  my $spri = $p->newSprite($id)->pan(1);
+
+  my $idw = $can->createText(0,0,
+			     '-text',substr($text,0,$len), 
+			     -tags => $id,
+			     @options
+			    );
+  my @bbox = $can->bbox($id);
+  my $larg = $bbox[2]-$bbox[0];
+  my $haut = $bbox[3]-$bbox[1];
+  my $bg = $can->cget(-background);
+  my $scan = $mw->Canvas(-height,$haut,-width,$larg,-background,$bg);
+  $can->createWindow($W/2,$H/2,'-anchor','nw','-window',$scan,'-tags',$id);
+  $can->delete($idw);
+  my @def = (-anchor, 'nw','-text',$text,'-tags' => $id, @options);
+  $idw = $scan->createText(0,0,@def);
+  @bbox = $scan->bbox($idw);
+  my $txtwidth = $bbox[2];
+  $scan->createText($txtwidth,0, @def);
+  $can->createRectangle($can->bbox($id),-width,20,-outline,$bg,-tags,$id);
+  sub tourne {
+    my ($spri,$scan,$txtwidth) = @_;
+    my $tag = $spri->id;
+    $scan->move($tag,-5,0);
+    $scan->move($tag, $txtwidth,0) if ($scan->bbox($tag))[2] < $scan->Width;
+    $can->after(50,[\&tourne,$spri,$scan,$txtwidth]);
+  }
+  tourne($spri,$scan,$txtwidth);
+  return $spri;
+}
 
 
 package Tk::SlideShow::Link;
